function [A1, B1, B2, B2p]=derive(f,v,vp,symb,nsymb);
% Returns the coefficient matrices (or numerical derivatives) of the model.
% Input:         f:  equilibrium system; 
%             v,vp:  variables and next period variables; 
%       symb,nsymb:  symbolic terms and its corresponding values
% Output:       A1: first order coefs of vp
%               B1: first order coefs of v
%               B2: second order coefs of v
%              B2p: second order coefs of vp
% Call: transformer.m
% Huabin Wu. Aug. 2009. Revised Apr. 2011.

nv = length(v);
symbb=[vp symb];
nsymbb=[nsymb(1:nv) nsymb];

fv    = jacobian(f,v); 
fvp   = jacobian(f,vp);
fvv   = jacobian(fv(:),v);
fvpvp = jacobian(fvp(:),vp);

A1 = -subs(fvp,symbb,nsymbb);
B1 = subs(fv,symbb,nsymbb);

nfvv   = subs(fvv,symbb,nsymbb);
nfvpvp = subs(fvpvp,symbb,nsymbb);

adj=-1/2*eye(nv)+ones(nv);

nfvv=reshape(nfvv,[nv,nv,nv]);
nfvv=permute(nfvv,[3,2,1]);
nfvv=(adj(:)*ones(1,nv)).*reshape(nfvv,[nv^2,nv]);

nfvpvp=reshape(nfvpvp,[nv,nv,nv]);
nfvpvp=permute(nfvpvp,[3,2,1]);
nfvpvp=(adj(:)*ones(1,nv)).*reshape(nfvpvp,[nv^2,nv]);

B2=zeros(nv,nv*(nv+1)/2);B2p=B2;
[L H]=transformer(nv);

for iv=1:nv
    B2(iv,:)=H*nfvv(:,iv);B2p(iv,:)=H*nfvpvp(:,iv);
end
