function [ir1 ir2] = easyirf2(C,S,CS2,SS2,Cs2,Ss2,sig,eee,idsh)
% Generate 2nd order IRFs.

% Input: 
% C: 1st order coefficient matrix for controls wrt states.
% S: 1st order evolution matrix for state variables.
% CS2: 2nd order coefficient matrix for controls wrt states.
% SS2: 2nd order coefficient matrix for states wrt states.
% Cs2: 2nd order coefficients for controls wrt perturbations.
% Ss2: 2nd order coefficients for states wrt perturbations.

% eee: series of shocks
% periods: the length of the IRFs path
% idsh: switcher for the shocks

% Output: [ir1 ir2] is 1st and 2nd order irfs respectively
% Huabin Wu. April 21, 2009. Revised Apr. 2011.
drop=200;periods=length(eee);
T=periods+drop;
[nc ns]=size(C);
S1=zeros(ns,T);S2=S1;
shock=[zeros(1,T-periods) eee];   
S1=idsh*sig*shock;

for iT =2:T
    % Pruning process===>>>
    S1(:,iT)= S*S1(:,iT-1)+idsh*sig*shock(iT);
    for iS=1:ns
    S2(iS,iT)= S(iS,:)*S2(:,iT-1)+.5*S1(:,iT-1)'*SS2(:,:,iS)'*S1(:,iT-1)...
                 +.5*Ss2(iS)*sig^2;
    end
end
C1=C*S1;C2=zeros(size(C1));
for iC=1:nc
    C2(iC,:)=C(iC,:)*S2+.5*sum(S1.*(CS2(:,:,iC)'*S1))+.5*Cs2(iC)*sig^2;
end
irs2=S1+S2;irc2=C1+C2;
ir1=[S1;C1];ir2=[irs2;irc2];
ir1=ir1(:,drop+1:end);
ir2=ir2(:,drop+1:end)-ir2(:,drop)*ones(1,periods);
