function D=eigvalue(eta)
% Return eigenvalues of the equilibrium system in Wen & Wu (2011).
% Wu, Huabin. Apr. 2008. Revised Apr. 2011.

bta=0.99; 
dlt=.025;
alf=0.3;
rho=0.9;
% eta=0; % increasing factor for maginal productivity
gam=0;

%---------------------Steady State-----------------------
ky=(bta*alf)/(1-bta*(1-dlt)); %k/y ratio
sy=dlt*ky; %saving ratio
cy=(1-sy); %c/y ratio

%================ Linearized Model ================

%--------------Coefficient Matrices----------------
etta = 1-bta*(1-dlt);
%matrix for labor
tmp=gam+1-(1+eta)*(1-alf);
coefl=[(1+eta)*alf/tmp  -1/tmp];

%lhs coefficient matrix 
lhsm = [((1+eta)*alf-1)*etta -1;
          sy/dlt	        0];

%rhs coeficient matrix       
rhsmk = [0	             	                  -1;
        sy*(1-dlt)/dlt+alf*(1+eta) 	-cy];
     
rhsmnp = [-etta*(1+eta)*(1-alf); 0];
rhsmn=[0;(1+eta)*(1-alf)];
rhsma=[-etta*rho;1];

%----------------- Reduced Form: X_t+1=W*X_t+RR*epsilon-----------
W = (lhsm-rhsmnp*coefl)\(rhsmk+rhsmn*coefl); 
RR = (lhsm-rhsmnp*coefl)\(rhsma+rhsmn/tmp+rhsmnp*rho/tmp);

%------------------Eigenvalue Decomposition-----------------
[V,D] = eig(W); %V is matrix of eigenvectors, D is diagnal matrix of eigenvalues;
D=diag(D);
